from typing import List

from openapi_client.models import (
    ClusterUpdateAPIInput,
    ResponseKernelClusterInfo,
    ResponseKernelClusterNodeInfo,
)
from vessl import vessl_api
from vessl.organization import _get_organization_name
from vessl.util.exception import InvalidKernelClusterError


def read_cluster(cluster_name: str, **kwargs) -> ResponseKernelClusterInfo:
    """Read cluster in the default organization. If you want to override the
    default organization, then pass `organization_name` as `**kwargs`.

    Args:
        cluster_name(str): Cluster name.

    Example:
        ```python
        vessl.read_cluster(
            cluster_name="seoul-cluster",
        )
        ```
    """
    kernel_clusters = list_clusters(**kwargs)
    kernel_clusters = {x.name: x for x in kernel_clusters}

    if cluster_name not in kernel_clusters:
        raise InvalidKernelClusterError(f"Kernel cluster not found: {cluster_name}")
    return kernel_clusters[cluster_name]


def list_clusters(**kwargs) -> List[ResponseKernelClusterInfo]:
    """List clusters in the default organization. If you want to override the
    default organization, then pass `organization_name` as `**kwargs`.

    Example:
        ```python
        vessl.list_clusters()
        ```
    """
    return vessl_api.cluster_list_api(
        organization_name=_get_organization_name(**kwargs),
    ).clusters


def delete_cluster(cluster_id: int, **kwargs) -> object:
    """Delete custom cluster in the default organization. If you want to
    override the default organization, then pass `organization_name` as
    `**kwargs`.

    Args:
        cluster_id(int): Cluster ID.

    Example:
        ```python
        vessl.delete_cluster(
            cluster_id=1,
        )
        ```
    """
    return vessl_api.custom_cluster_delete_api(
        cluster_id=cluster_id,
        organization_name=_get_organization_name(**kwargs),
    )


def rename_cluster(
    cluster_id: int, new_cluster_name: str, **kwargs
) -> ResponseKernelClusterInfo:
    """Rename custom cluster in the default organization. If you want to
    override the default organization, then pass `organization_name` as
    `**kwargs`.

    Args:
        cluster_id(int): Cluster ID.
        new_cluster_name(str): Cluster name to change.

    Example:
        ```python
        vessl.rename_cluster(
            cluster_id=1,
            new_cluster_name="seoul-cluster-2",
        )
        ```
    """
    return vessl_api.custom_cluster_update_api(
        cluster_id=cluster_id,
        organization_name=_get_organization_name(**kwargs),
        custom_cluster_update_api_input=ClusterUpdateAPIInput(
            name=new_cluster_name,
        ),
    )


def list_cluster_nodes(
    cluster_id: int, **kwargs
) -> List[ResponseKernelClusterNodeInfo]:
    """List custom cluster nodes in the default organization. If you want to
    override the default organization, then pass `organization_name` as
    `**kwargs`.

    Args:
        cluster_id(int): Cluster ID.

    Example:
        ```python
        vessl.list_cluster_nodes(
            cluster_id=1,
        )
        ```
    """
    return vessl_api.custom_cluster_node_list_api(
        cluster_id=cluster_id,
        organization_name=_get_organization_name(**kwargs),
    ).nodes



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class SweepCreateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'algorithm': 'str',
        'cluster_id': 'int',
        'cluster_node_ids': 'list[int]',
        'docker_credentials_id': 'int',
        'early_stopping_spec': 'OrmEarlyStoppingSpec',
        'hyperparameters': 'list[OrmHyperparameter]',
        'image_url': 'str',
        'max_experiment_count': 'int',
        'max_failed_experiment_count': 'int',
        'message': 'str',
        'objective': 'OrmSweepObjective',
        'parallel_experiment_count': 'int',
        'resource_spec': 'OrmKernelResourceSpecField',
        'resource_spec_id': 'int',
        'search_space': 'OrmSweepSearchSpace',
        'start_command': 'str',
        'volumes': 'ProtoVolumeMountRequests'
    }

    attribute_map = {
        'algorithm': 'algorithm',
        'cluster_id': 'cluster_id',
        'cluster_node_ids': 'cluster_node_ids',
        'docker_credentials_id': 'docker_credentials_id',
        'early_stopping_spec': 'early_stopping_spec',
        'hyperparameters': 'hyperparameters',
        'image_url': 'image_url',
        'max_experiment_count': 'max_experiment_count',
        'max_failed_experiment_count': 'max_failed_experiment_count',
        'message': 'message',
        'objective': 'objective',
        'parallel_experiment_count': 'parallel_experiment_count',
        'resource_spec': 'resource_spec',
        'resource_spec_id': 'resource_spec_id',
        'search_space': 'search_space',
        'start_command': 'start_command',
        'volumes': 'volumes'
    }

    def __init__(self, algorithm=None, cluster_id=None, cluster_node_ids=None, docker_credentials_id=None, early_stopping_spec=None, hyperparameters=None, image_url=None, max_experiment_count=None, max_failed_experiment_count=None, message=None, objective=None, parallel_experiment_count=None, resource_spec=None, resource_spec_id=None, search_space=None, start_command=None, volumes=None, local_vars_configuration=None):  # noqa: E501
        """SweepCreateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._algorithm = None
        self._cluster_id = None
        self._cluster_node_ids = None
        self._docker_credentials_id = None
        self._early_stopping_spec = None
        self._hyperparameters = None
        self._image_url = None
        self._max_experiment_count = None
        self._max_failed_experiment_count = None
        self._message = None
        self._objective = None
        self._parallel_experiment_count = None
        self._resource_spec = None
        self._resource_spec_id = None
        self._search_space = None
        self._start_command = None
        self._volumes = None
        self.discriminator = None

        self.algorithm = algorithm
        self.cluster_id = cluster_id
        if cluster_node_ids is not None:
            self.cluster_node_ids = cluster_node_ids
        self.docker_credentials_id = docker_credentials_id
        if early_stopping_spec is not None:
            self.early_stopping_spec = early_stopping_spec
        if hyperparameters is not None:
            self.hyperparameters = hyperparameters
        self.image_url = image_url
        self.max_experiment_count = max_experiment_count
        self.max_failed_experiment_count = max_failed_experiment_count
        self.message = message
        self.objective = objective
        self.parallel_experiment_count = parallel_experiment_count
        if resource_spec is not None:
            self.resource_spec = resource_spec
        self.resource_spec_id = resource_spec_id
        self.search_space = search_space
        self.start_command = start_command
        self.volumes = volumes

    @property
    def algorithm(self):
        """Gets the algorithm of this SweepCreateAPIInput.  # noqa: E501


        :return: The algorithm of this SweepCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this SweepCreateAPIInput.


        :param algorithm: The algorithm of this SweepCreateAPIInput.  # noqa: E501
        :type algorithm: str
        """
        if self.local_vars_configuration.client_side_validation and algorithm is None:  # noqa: E501
            raise ValueError("Invalid value for `algorithm`, must not be `None`")  # noqa: E501

        self._algorithm = algorithm

    @property
    def cluster_id(self):
        """Gets the cluster_id of this SweepCreateAPIInput.  # noqa: E501


        :return: The cluster_id of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this SweepCreateAPIInput.


        :param cluster_id: The cluster_id of this SweepCreateAPIInput.  # noqa: E501
        :type cluster_id: int
        """
        if self.local_vars_configuration.client_side_validation and cluster_id is None:  # noqa: E501
            raise ValueError("Invalid value for `cluster_id`, must not be `None`")  # noqa: E501

        self._cluster_id = cluster_id

    @property
    def cluster_node_ids(self):
        """Gets the cluster_node_ids of this SweepCreateAPIInput.  # noqa: E501


        :return: The cluster_node_ids of this SweepCreateAPIInput.  # noqa: E501
        :rtype: list[int]
        """
        return self._cluster_node_ids

    @cluster_node_ids.setter
    def cluster_node_ids(self, cluster_node_ids):
        """Sets the cluster_node_ids of this SweepCreateAPIInput.


        :param cluster_node_ids: The cluster_node_ids of this SweepCreateAPIInput.  # noqa: E501
        :type cluster_node_ids: list[int]
        """

        self._cluster_node_ids = cluster_node_ids

    @property
    def docker_credentials_id(self):
        """Gets the docker_credentials_id of this SweepCreateAPIInput.  # noqa: E501


        :return: The docker_credentials_id of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._docker_credentials_id

    @docker_credentials_id.setter
    def docker_credentials_id(self, docker_credentials_id):
        """Sets the docker_credentials_id of this SweepCreateAPIInput.


        :param docker_credentials_id: The docker_credentials_id of this SweepCreateAPIInput.  # noqa: E501
        :type docker_credentials_id: int
        """

        self._docker_credentials_id = docker_credentials_id

    @property
    def early_stopping_spec(self):
        """Gets the early_stopping_spec of this SweepCreateAPIInput.  # noqa: E501


        :return: The early_stopping_spec of this SweepCreateAPIInput.  # noqa: E501
        :rtype: OrmEarlyStoppingSpec
        """
        return self._early_stopping_spec

    @early_stopping_spec.setter
    def early_stopping_spec(self, early_stopping_spec):
        """Sets the early_stopping_spec of this SweepCreateAPIInput.


        :param early_stopping_spec: The early_stopping_spec of this SweepCreateAPIInput.  # noqa: E501
        :type early_stopping_spec: OrmEarlyStoppingSpec
        """

        self._early_stopping_spec = early_stopping_spec

    @property
    def hyperparameters(self):
        """Gets the hyperparameters of this SweepCreateAPIInput.  # noqa: E501


        :return: The hyperparameters of this SweepCreateAPIInput.  # noqa: E501
        :rtype: list[OrmHyperparameter]
        """
        return self._hyperparameters

    @hyperparameters.setter
    def hyperparameters(self, hyperparameters):
        """Sets the hyperparameters of this SweepCreateAPIInput.


        :param hyperparameters: The hyperparameters of this SweepCreateAPIInput.  # noqa: E501
        :type hyperparameters: list[OrmHyperparameter]
        """

        self._hyperparameters = hyperparameters

    @property
    def image_url(self):
        """Gets the image_url of this SweepCreateAPIInput.  # noqa: E501


        :return: The image_url of this SweepCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this SweepCreateAPIInput.


        :param image_url: The image_url of this SweepCreateAPIInput.  # noqa: E501
        :type image_url: str
        """
        if self.local_vars_configuration.client_side_validation and image_url is None:  # noqa: E501
            raise ValueError("Invalid value for `image_url`, must not be `None`")  # noqa: E501

        self._image_url = image_url

    @property
    def max_experiment_count(self):
        """Gets the max_experiment_count of this SweepCreateAPIInput.  # noqa: E501


        :return: The max_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._max_experiment_count

    @max_experiment_count.setter
    def max_experiment_count(self, max_experiment_count):
        """Sets the max_experiment_count of this SweepCreateAPIInput.


        :param max_experiment_count: The max_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :type max_experiment_count: int
        """
        if self.local_vars_configuration.client_side_validation and max_experiment_count is None:  # noqa: E501
            raise ValueError("Invalid value for `max_experiment_count`, must not be `None`")  # noqa: E501

        self._max_experiment_count = max_experiment_count

    @property
    def max_failed_experiment_count(self):
        """Gets the max_failed_experiment_count of this SweepCreateAPIInput.  # noqa: E501


        :return: The max_failed_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._max_failed_experiment_count

    @max_failed_experiment_count.setter
    def max_failed_experiment_count(self, max_failed_experiment_count):
        """Sets the max_failed_experiment_count of this SweepCreateAPIInput.


        :param max_failed_experiment_count: The max_failed_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :type max_failed_experiment_count: int
        """
        if self.local_vars_configuration.client_side_validation and max_failed_experiment_count is None:  # noqa: E501
            raise ValueError("Invalid value for `max_failed_experiment_count`, must not be `None`")  # noqa: E501

        self._max_failed_experiment_count = max_failed_experiment_count

    @property
    def message(self):
        """Gets the message of this SweepCreateAPIInput.  # noqa: E501


        :return: The message of this SweepCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this SweepCreateAPIInput.


        :param message: The message of this SweepCreateAPIInput.  # noqa: E501
        :type message: str
        """
        if (self.local_vars_configuration.client_side_validation and
                message is not None and len(message) > 255):
            raise ValueError("Invalid value for `message`, length must be less than or equal to `255`")  # noqa: E501

        self._message = message

    @property
    def objective(self):
        """Gets the objective of this SweepCreateAPIInput.  # noqa: E501


        :return: The objective of this SweepCreateAPIInput.  # noqa: E501
        :rtype: OrmSweepObjective
        """
        return self._objective

    @objective.setter
    def objective(self, objective):
        """Sets the objective of this SweepCreateAPIInput.


        :param objective: The objective of this SweepCreateAPIInput.  # noqa: E501
        :type objective: OrmSweepObjective
        """
        if self.local_vars_configuration.client_side_validation and objective is None:  # noqa: E501
            raise ValueError("Invalid value for `objective`, must not be `None`")  # noqa: E501

        self._objective = objective

    @property
    def parallel_experiment_count(self):
        """Gets the parallel_experiment_count of this SweepCreateAPIInput.  # noqa: E501


        :return: The parallel_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._parallel_experiment_count

    @parallel_experiment_count.setter
    def parallel_experiment_count(self, parallel_experiment_count):
        """Sets the parallel_experiment_count of this SweepCreateAPIInput.


        :param parallel_experiment_count: The parallel_experiment_count of this SweepCreateAPIInput.  # noqa: E501
        :type parallel_experiment_count: int
        """
        if self.local_vars_configuration.client_side_validation and parallel_experiment_count is None:  # noqa: E501
            raise ValueError("Invalid value for `parallel_experiment_count`, must not be `None`")  # noqa: E501

        self._parallel_experiment_count = parallel_experiment_count

    @property
    def resource_spec(self):
        """Gets the resource_spec of this SweepCreateAPIInput.  # noqa: E501


        :return: The resource_spec of this SweepCreateAPIInput.  # noqa: E501
        :rtype: OrmKernelResourceSpecField
        """
        return self._resource_spec

    @resource_spec.setter
    def resource_spec(self, resource_spec):
        """Sets the resource_spec of this SweepCreateAPIInput.


        :param resource_spec: The resource_spec of this SweepCreateAPIInput.  # noqa: E501
        :type resource_spec: OrmKernelResourceSpecField
        """

        self._resource_spec = resource_spec

    @property
    def resource_spec_id(self):
        """Gets the resource_spec_id of this SweepCreateAPIInput.  # noqa: E501


        :return: The resource_spec_id of this SweepCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._resource_spec_id

    @resource_spec_id.setter
    def resource_spec_id(self, resource_spec_id):
        """Sets the resource_spec_id of this SweepCreateAPIInput.


        :param resource_spec_id: The resource_spec_id of this SweepCreateAPIInput.  # noqa: E501
        :type resource_spec_id: int
        """

        self._resource_spec_id = resource_spec_id

    @property
    def search_space(self):
        """Gets the search_space of this SweepCreateAPIInput.  # noqa: E501


        :return: The search_space of this SweepCreateAPIInput.  # noqa: E501
        :rtype: OrmSweepSearchSpace
        """
        return self._search_space

    @search_space.setter
    def search_space(self, search_space):
        """Sets the search_space of this SweepCreateAPIInput.


        :param search_space: The search_space of this SweepCreateAPIInput.  # noqa: E501
        :type search_space: OrmSweepSearchSpace
        """
        if self.local_vars_configuration.client_side_validation and search_space is None:  # noqa: E501
            raise ValueError("Invalid value for `search_space`, must not be `None`")  # noqa: E501

        self._search_space = search_space

    @property
    def start_command(self):
        """Gets the start_command of this SweepCreateAPIInput.  # noqa: E501


        :return: The start_command of this SweepCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this SweepCreateAPIInput.


        :param start_command: The start_command of this SweepCreateAPIInput.  # noqa: E501
        :type start_command: str
        """
        if self.local_vars_configuration.client_side_validation and start_command is None:  # noqa: E501
            raise ValueError("Invalid value for `start_command`, must not be `None`")  # noqa: E501

        self._start_command = start_command

    @property
    def volumes(self):
        """Gets the volumes of this SweepCreateAPIInput.  # noqa: E501


        :return: The volumes of this SweepCreateAPIInput.  # noqa: E501
        :rtype: ProtoVolumeMountRequests
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this SweepCreateAPIInput.


        :param volumes: The volumes of this SweepCreateAPIInput.  # noqa: E501
        :type volumes: ProtoVolumeMountRequests
        """
        if self.local_vars_configuration.client_side_validation and volumes is None:  # noqa: E501
            raise ValueError("Invalid value for `volumes`, must not be `None`")  # noqa: E501

        self._volumes = volumes

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SweepCreateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SweepCreateAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmWorkloadEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'billing_histories': 'list[OrmBillingHistory]',
        'experiment': 'OrmExperiment',
        'histories': 'list[OrmWorkloadHistory]',
        'kernel_cluster': 'OrmKernelCluster',
        'kernel_cluster_node': 'OrmKernelClusterNode',
        'kernel_image': 'OrmKernelImage',
        'kernel_resource_spec': 'OrmKernelResourceSpec',
        'service': 'OrmService',
        'workspace': 'OrmWorkspace'
    }

    attribute_map = {
        'billing_histories': 'billing_histories',
        'experiment': 'experiment',
        'histories': 'histories',
        'kernel_cluster': 'kernel_cluster',
        'kernel_cluster_node': 'kernel_cluster_node',
        'kernel_image': 'kernel_image',
        'kernel_resource_spec': 'kernel_resource_spec',
        'service': 'service',
        'workspace': 'workspace'
    }

    def __init__(self, billing_histories=None, experiment=None, histories=None, kernel_cluster=None, kernel_cluster_node=None, kernel_image=None, kernel_resource_spec=None, service=None, workspace=None, local_vars_configuration=None):  # noqa: E501
        """OrmWorkloadEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._billing_histories = None
        self._experiment = None
        self._histories = None
        self._kernel_cluster = None
        self._kernel_cluster_node = None
        self._kernel_image = None
        self._kernel_resource_spec = None
        self._service = None
        self._workspace = None
        self.discriminator = None

        if billing_histories is not None:
            self.billing_histories = billing_histories
        if experiment is not None:
            self.experiment = experiment
        if histories is not None:
            self.histories = histories
        if kernel_cluster is not None:
            self.kernel_cluster = kernel_cluster
        if kernel_cluster_node is not None:
            self.kernel_cluster_node = kernel_cluster_node
        if kernel_image is not None:
            self.kernel_image = kernel_image
        if kernel_resource_spec is not None:
            self.kernel_resource_spec = kernel_resource_spec
        if service is not None:
            self.service = service
        if workspace is not None:
            self.workspace = workspace

    @property
    def billing_histories(self):
        """Gets the billing_histories of this OrmWorkloadEdges.  # noqa: E501


        :return: The billing_histories of this OrmWorkloadEdges.  # noqa: E501
        :rtype: list[OrmBillingHistory]
        """
        return self._billing_histories

    @billing_histories.setter
    def billing_histories(self, billing_histories):
        """Sets the billing_histories of this OrmWorkloadEdges.


        :param billing_histories: The billing_histories of this OrmWorkloadEdges.  # noqa: E501
        :type billing_histories: list[OrmBillingHistory]
        """

        self._billing_histories = billing_histories

    @property
    def experiment(self):
        """Gets the experiment of this OrmWorkloadEdges.  # noqa: E501


        :return: The experiment of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmExperiment
        """
        return self._experiment

    @experiment.setter
    def experiment(self, experiment):
        """Sets the experiment of this OrmWorkloadEdges.


        :param experiment: The experiment of this OrmWorkloadEdges.  # noqa: E501
        :type experiment: OrmExperiment
        """

        self._experiment = experiment

    @property
    def histories(self):
        """Gets the histories of this OrmWorkloadEdges.  # noqa: E501


        :return: The histories of this OrmWorkloadEdges.  # noqa: E501
        :rtype: list[OrmWorkloadHistory]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this OrmWorkloadEdges.


        :param histories: The histories of this OrmWorkloadEdges.  # noqa: E501
        :type histories: list[OrmWorkloadHistory]
        """

        self._histories = histories

    @property
    def kernel_cluster(self):
        """Gets the kernel_cluster of this OrmWorkloadEdges.  # noqa: E501


        :return: The kernel_cluster of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmKernelCluster
        """
        return self._kernel_cluster

    @kernel_cluster.setter
    def kernel_cluster(self, kernel_cluster):
        """Sets the kernel_cluster of this OrmWorkloadEdges.


        :param kernel_cluster: The kernel_cluster of this OrmWorkloadEdges.  # noqa: E501
        :type kernel_cluster: OrmKernelCluster
        """

        self._kernel_cluster = kernel_cluster

    @property
    def kernel_cluster_node(self):
        """Gets the kernel_cluster_node of this OrmWorkloadEdges.  # noqa: E501


        :return: The kernel_cluster_node of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmKernelClusterNode
        """
        return self._kernel_cluster_node

    @kernel_cluster_node.setter
    def kernel_cluster_node(self, kernel_cluster_node):
        """Sets the kernel_cluster_node of this OrmWorkloadEdges.


        :param kernel_cluster_node: The kernel_cluster_node of this OrmWorkloadEdges.  # noqa: E501
        :type kernel_cluster_node: OrmKernelClusterNode
        """

        self._kernel_cluster_node = kernel_cluster_node

    @property
    def kernel_image(self):
        """Gets the kernel_image of this OrmWorkloadEdges.  # noqa: E501


        :return: The kernel_image of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this OrmWorkloadEdges.


        :param kernel_image: The kernel_image of this OrmWorkloadEdges.  # noqa: E501
        :type kernel_image: OrmKernelImage
        """

        self._kernel_image = kernel_image

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this OrmWorkloadEdges.  # noqa: E501


        :return: The kernel_resource_spec of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this OrmWorkloadEdges.


        :param kernel_resource_spec: The kernel_resource_spec of this OrmWorkloadEdges.  # noqa: E501
        :type kernel_resource_spec: OrmKernelResourceSpec
        """

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def service(self):
        """Gets the service of this OrmWorkloadEdges.  # noqa: E501


        :return: The service of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmService
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this OrmWorkloadEdges.


        :param service: The service of this OrmWorkloadEdges.  # noqa: E501
        :type service: OrmService
        """

        self._service = service

    @property
    def workspace(self):
        """Gets the workspace of this OrmWorkloadEdges.  # noqa: E501


        :return: The workspace of this OrmWorkloadEdges.  # noqa: E501
        :rtype: OrmWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this OrmWorkloadEdges.


        :param workspace: The workspace of this OrmWorkloadEdges.  # noqa: E501
        :type workspace: OrmWorkspace
        """

        self._workspace = workspace

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmWorkloadEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmWorkloadEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmKernelClusterEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'kernel_cluster_nodes': 'list[OrmKernelClusterNode]',
        'kernel_cluster_storages': 'list[OrmKernelClusterStorage]',
        'kernel_cluster_workloads': 'list[OrmWorkload]',
        'kernel_resource_specs': 'list[OrmKernelResourceSpec]',
        'organization_kernel_clusters': 'list[OrmOrganizationKernelCluster]',
        'region': 'OrmRegion'
    }

    attribute_map = {
        'kernel_cluster_nodes': 'kernel_cluster_nodes',
        'kernel_cluster_storages': 'kernel_cluster_storages',
        'kernel_cluster_workloads': 'kernel_cluster_workloads',
        'kernel_resource_specs': 'kernel_resource_specs',
        'organization_kernel_clusters': 'organization_kernel_clusters',
        'region': 'region'
    }

    def __init__(self, kernel_cluster_nodes=None, kernel_cluster_storages=None, kernel_cluster_workloads=None, kernel_resource_specs=None, organization_kernel_clusters=None, region=None, local_vars_configuration=None):  # noqa: E501
        """OrmKernelClusterEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._kernel_cluster_nodes = None
        self._kernel_cluster_storages = None
        self._kernel_cluster_workloads = None
        self._kernel_resource_specs = None
        self._organization_kernel_clusters = None
        self._region = None
        self.discriminator = None

        if kernel_cluster_nodes is not None:
            self.kernel_cluster_nodes = kernel_cluster_nodes
        if kernel_cluster_storages is not None:
            self.kernel_cluster_storages = kernel_cluster_storages
        if kernel_cluster_workloads is not None:
            self.kernel_cluster_workloads = kernel_cluster_workloads
        if kernel_resource_specs is not None:
            self.kernel_resource_specs = kernel_resource_specs
        if organization_kernel_clusters is not None:
            self.organization_kernel_clusters = organization_kernel_clusters
        if region is not None:
            self.region = region

    @property
    def kernel_cluster_nodes(self):
        """Gets the kernel_cluster_nodes of this OrmKernelClusterEdges.  # noqa: E501


        :return: The kernel_cluster_nodes of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: list[OrmKernelClusterNode]
        """
        return self._kernel_cluster_nodes

    @kernel_cluster_nodes.setter
    def kernel_cluster_nodes(self, kernel_cluster_nodes):
        """Sets the kernel_cluster_nodes of this OrmKernelClusterEdges.


        :param kernel_cluster_nodes: The kernel_cluster_nodes of this OrmKernelClusterEdges.  # noqa: E501
        :type kernel_cluster_nodes: list[OrmKernelClusterNode]
        """

        self._kernel_cluster_nodes = kernel_cluster_nodes

    @property
    def kernel_cluster_storages(self):
        """Gets the kernel_cluster_storages of this OrmKernelClusterEdges.  # noqa: E501


        :return: The kernel_cluster_storages of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: list[OrmKernelClusterStorage]
        """
        return self._kernel_cluster_storages

    @kernel_cluster_storages.setter
    def kernel_cluster_storages(self, kernel_cluster_storages):
        """Sets the kernel_cluster_storages of this OrmKernelClusterEdges.


        :param kernel_cluster_storages: The kernel_cluster_storages of this OrmKernelClusterEdges.  # noqa: E501
        :type kernel_cluster_storages: list[OrmKernelClusterStorage]
        """

        self._kernel_cluster_storages = kernel_cluster_storages

    @property
    def kernel_cluster_workloads(self):
        """Gets the kernel_cluster_workloads of this OrmKernelClusterEdges.  # noqa: E501


        :return: The kernel_cluster_workloads of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: list[OrmWorkload]
        """
        return self._kernel_cluster_workloads

    @kernel_cluster_workloads.setter
    def kernel_cluster_workloads(self, kernel_cluster_workloads):
        """Sets the kernel_cluster_workloads of this OrmKernelClusterEdges.


        :param kernel_cluster_workloads: The kernel_cluster_workloads of this OrmKernelClusterEdges.  # noqa: E501
        :type kernel_cluster_workloads: list[OrmWorkload]
        """

        self._kernel_cluster_workloads = kernel_cluster_workloads

    @property
    def kernel_resource_specs(self):
        """Gets the kernel_resource_specs of this OrmKernelClusterEdges.  # noqa: E501


        :return: The kernel_resource_specs of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: list[OrmKernelResourceSpec]
        """
        return self._kernel_resource_specs

    @kernel_resource_specs.setter
    def kernel_resource_specs(self, kernel_resource_specs):
        """Sets the kernel_resource_specs of this OrmKernelClusterEdges.


        :param kernel_resource_specs: The kernel_resource_specs of this OrmKernelClusterEdges.  # noqa: E501
        :type kernel_resource_specs: list[OrmKernelResourceSpec]
        """

        self._kernel_resource_specs = kernel_resource_specs

    @property
    def organization_kernel_clusters(self):
        """Gets the organization_kernel_clusters of this OrmKernelClusterEdges.  # noqa: E501


        :return: The organization_kernel_clusters of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: list[OrmOrganizationKernelCluster]
        """
        return self._organization_kernel_clusters

    @organization_kernel_clusters.setter
    def organization_kernel_clusters(self, organization_kernel_clusters):
        """Sets the organization_kernel_clusters of this OrmKernelClusterEdges.


        :param organization_kernel_clusters: The organization_kernel_clusters of this OrmKernelClusterEdges.  # noqa: E501
        :type organization_kernel_clusters: list[OrmOrganizationKernelCluster]
        """

        self._organization_kernel_clusters = organization_kernel_clusters

    @property
    def region(self):
        """Gets the region of this OrmKernelClusterEdges.  # noqa: E501


        :return: The region of this OrmKernelClusterEdges.  # noqa: E501
        :rtype: OrmRegion
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this OrmKernelClusterEdges.


        :param region: The region of this OrmKernelClusterEdges.  # noqa: E501
        :type region: OrmRegion
        """

        self._region = region

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmKernelClusterEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmKernelClusterEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmOrganization(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_external_id': 'str',
        'created_dt': 'datetime',
        'credit_balance': 'float',
        'default_region': 'str',
        'description': 'str',
        'display_name': 'str',
        'edges': 'OrmOrganizationEdges',
        'fixed_cost': 'float',
        'id': 'int',
        'immutable_slug': 'str',
        'is_public': 'bool',
        'name': 'str',
        'on_demand_discount_rate': 'float',
        'on_premise_discount_rate': 'float',
        'organization_default_storage': 'int',
        'organization_default_volume': 'int',
        'organization_pricing_plan': 'int',
        'organization_primary_owner': 'int',
        'stripe_customer_id': 'str',
        'stripe_subscription_id': 'str',
        'stripe_subscription_items': 'dict(str, object)',
        'updated_dt': 'datetime',
        'user_discount_rate': 'float'
    }

    attribute_map = {
        'aws_external_id': 'aws_external_id',
        'created_dt': 'created_dt',
        'credit_balance': 'credit_balance',
        'default_region': 'default_region',
        'description': 'description',
        'display_name': 'display_name',
        'edges': 'edges',
        'fixed_cost': 'fixed_cost',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'is_public': 'is_public',
        'name': 'name',
        'on_demand_discount_rate': 'on_demand_discount_rate',
        'on_premise_discount_rate': 'on_premise_discount_rate',
        'organization_default_storage': 'organization_default_storage',
        'organization_default_volume': 'organization_default_volume',
        'organization_pricing_plan': 'organization_pricing_plan',
        'organization_primary_owner': 'organization_primary_owner',
        'stripe_customer_id': 'stripe_customer_id',
        'stripe_subscription_id': 'stripe_subscription_id',
        'stripe_subscription_items': 'stripe_subscription_items',
        'updated_dt': 'updated_dt',
        'user_discount_rate': 'user_discount_rate'
    }

    def __init__(self, aws_external_id=None, created_dt=None, credit_balance=None, default_region=None, description=None, display_name=None, edges=None, fixed_cost=None, id=None, immutable_slug=None, is_public=None, name=None, on_demand_discount_rate=None, on_premise_discount_rate=None, organization_default_storage=None, organization_default_volume=None, organization_pricing_plan=None, organization_primary_owner=None, stripe_customer_id=None, stripe_subscription_id=None, stripe_subscription_items=None, updated_dt=None, user_discount_rate=None, local_vars_configuration=None):  # noqa: E501
        """OrmOrganization - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws_external_id = None
        self._created_dt = None
        self._credit_balance = None
        self._default_region = None
        self._description = None
        self._display_name = None
        self._edges = None
        self._fixed_cost = None
        self._id = None
        self._immutable_slug = None
        self._is_public = None
        self._name = None
        self._on_demand_discount_rate = None
        self._on_premise_discount_rate = None
        self._organization_default_storage = None
        self._organization_default_volume = None
        self._organization_pricing_plan = None
        self._organization_primary_owner = None
        self._stripe_customer_id = None
        self._stripe_subscription_id = None
        self._stripe_subscription_items = None
        self._updated_dt = None
        self._user_discount_rate = None
        self.discriminator = None

        if aws_external_id is not None:
            self.aws_external_id = aws_external_id
        if created_dt is not None:
            self.created_dt = created_dt
        if credit_balance is not None:
            self.credit_balance = credit_balance
        if default_region is not None:
            self.default_region = default_region
        self.description = description
        if display_name is not None:
            self.display_name = display_name
        if edges is not None:
            self.edges = edges
        if fixed_cost is not None:
            self.fixed_cost = fixed_cost
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if is_public is not None:
            self.is_public = is_public
        if name is not None:
            self.name = name
        if on_demand_discount_rate is not None:
            self.on_demand_discount_rate = on_demand_discount_rate
        if on_premise_discount_rate is not None:
            self.on_premise_discount_rate = on_premise_discount_rate
        self.organization_default_storage = organization_default_storage
        self.organization_default_volume = organization_default_volume
        if organization_pricing_plan is not None:
            self.organization_pricing_plan = organization_pricing_plan
        if organization_primary_owner is not None:
            self.organization_primary_owner = organization_primary_owner
        self.stripe_customer_id = stripe_customer_id
        self.stripe_subscription_id = stripe_subscription_id
        if stripe_subscription_items is not None:
            self.stripe_subscription_items = stripe_subscription_items
        if updated_dt is not None:
            self.updated_dt = updated_dt
        if user_discount_rate is not None:
            self.user_discount_rate = user_discount_rate

    @property
    def aws_external_id(self):
        """Gets the aws_external_id of this OrmOrganization.  # noqa: E501


        :return: The aws_external_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._aws_external_id

    @aws_external_id.setter
    def aws_external_id(self, aws_external_id):
        """Sets the aws_external_id of this OrmOrganization.


        :param aws_external_id: The aws_external_id of this OrmOrganization.  # noqa: E501
        :type aws_external_id: str
        """

        self._aws_external_id = aws_external_id

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmOrganization.  # noqa: E501


        :return: The created_dt of this OrmOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmOrganization.


        :param created_dt: The created_dt of this OrmOrganization.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def credit_balance(self):
        """Gets the credit_balance of this OrmOrganization.  # noqa: E501


        :return: The credit_balance of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._credit_balance

    @credit_balance.setter
    def credit_balance(self, credit_balance):
        """Sets the credit_balance of this OrmOrganization.


        :param credit_balance: The credit_balance of this OrmOrganization.  # noqa: E501
        :type credit_balance: float
        """

        self._credit_balance = credit_balance

    @property
    def default_region(self):
        """Gets the default_region of this OrmOrganization.  # noqa: E501


        :return: The default_region of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._default_region

    @default_region.setter
    def default_region(self, default_region):
        """Sets the default_region of this OrmOrganization.


        :param default_region: The default_region of this OrmOrganization.  # noqa: E501
        :type default_region: str
        """

        self._default_region = default_region

    @property
    def description(self):
        """Gets the description of this OrmOrganization.  # noqa: E501


        :return: The description of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmOrganization.


        :param description: The description of this OrmOrganization.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this OrmOrganization.  # noqa: E501


        :return: The display_name of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this OrmOrganization.


        :param display_name: The display_name of this OrmOrganization.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def edges(self):
        """Gets the edges of this OrmOrganization.  # noqa: E501


        :return: The edges of this OrmOrganization.  # noqa: E501
        :rtype: OrmOrganizationEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmOrganization.


        :param edges: The edges of this OrmOrganization.  # noqa: E501
        :type edges: OrmOrganizationEdges
        """

        self._edges = edges

    @property
    def fixed_cost(self):
        """Gets the fixed_cost of this OrmOrganization.  # noqa: E501


        :return: The fixed_cost of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._fixed_cost

    @fixed_cost.setter
    def fixed_cost(self, fixed_cost):
        """Sets the fixed_cost of this OrmOrganization.


        :param fixed_cost: The fixed_cost of this OrmOrganization.  # noqa: E501
        :type fixed_cost: float
        """

        self._fixed_cost = fixed_cost

    @property
    def id(self):
        """Gets the id of this OrmOrganization.  # noqa: E501


        :return: The id of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmOrganization.


        :param id: The id of this OrmOrganization.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmOrganization.  # noqa: E501


        :return: The immutable_slug of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmOrganization.


        :param immutable_slug: The immutable_slug of this OrmOrganization.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def is_public(self):
        """Gets the is_public of this OrmOrganization.  # noqa: E501


        :return: The is_public of this OrmOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this OrmOrganization.


        :param is_public: The is_public of this OrmOrganization.  # noqa: E501
        :type is_public: bool
        """

        self._is_public = is_public

    @property
    def name(self):
        """Gets the name of this OrmOrganization.  # noqa: E501


        :return: The name of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmOrganization.


        :param name: The name of this OrmOrganization.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def on_demand_discount_rate(self):
        """Gets the on_demand_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The on_demand_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._on_demand_discount_rate

    @on_demand_discount_rate.setter
    def on_demand_discount_rate(self, on_demand_discount_rate):
        """Sets the on_demand_discount_rate of this OrmOrganization.


        :param on_demand_discount_rate: The on_demand_discount_rate of this OrmOrganization.  # noqa: E501
        :type on_demand_discount_rate: float
        """

        self._on_demand_discount_rate = on_demand_discount_rate

    @property
    def on_premise_discount_rate(self):
        """Gets the on_premise_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The on_premise_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._on_premise_discount_rate

    @on_premise_discount_rate.setter
    def on_premise_discount_rate(self, on_premise_discount_rate):
        """Sets the on_premise_discount_rate of this OrmOrganization.


        :param on_premise_discount_rate: The on_premise_discount_rate of this OrmOrganization.  # noqa: E501
        :type on_premise_discount_rate: float
        """

        self._on_premise_discount_rate = on_premise_discount_rate

    @property
    def organization_default_storage(self):
        """Gets the organization_default_storage of this OrmOrganization.  # noqa: E501


        :return: The organization_default_storage of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_default_storage

    @organization_default_storage.setter
    def organization_default_storage(self, organization_default_storage):
        """Sets the organization_default_storage of this OrmOrganization.


        :param organization_default_storage: The organization_default_storage of this OrmOrganization.  # noqa: E501
        :type organization_default_storage: int
        """

        self._organization_default_storage = organization_default_storage

    @property
    def organization_default_volume(self):
        """Gets the organization_default_volume of this OrmOrganization.  # noqa: E501


        :return: The organization_default_volume of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_default_volume

    @organization_default_volume.setter
    def organization_default_volume(self, organization_default_volume):
        """Sets the organization_default_volume of this OrmOrganization.


        :param organization_default_volume: The organization_default_volume of this OrmOrganization.  # noqa: E501
        :type organization_default_volume: int
        """

        self._organization_default_volume = organization_default_volume

    @property
    def organization_pricing_plan(self):
        """Gets the organization_pricing_plan of this OrmOrganization.  # noqa: E501


        :return: The organization_pricing_plan of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_pricing_plan

    @organization_pricing_plan.setter
    def organization_pricing_plan(self, organization_pricing_plan):
        """Sets the organization_pricing_plan of this OrmOrganization.


        :param organization_pricing_plan: The organization_pricing_plan of this OrmOrganization.  # noqa: E501
        :type organization_pricing_plan: int
        """

        self._organization_pricing_plan = organization_pricing_plan

    @property
    def organization_primary_owner(self):
        """Gets the organization_primary_owner of this OrmOrganization.  # noqa: E501


        :return: The organization_primary_owner of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_primary_owner

    @organization_primary_owner.setter
    def organization_primary_owner(self, organization_primary_owner):
        """Sets the organization_primary_owner of this OrmOrganization.


        :param organization_primary_owner: The organization_primary_owner of this OrmOrganization.  # noqa: E501
        :type organization_primary_owner: int
        """

        self._organization_primary_owner = organization_primary_owner

    @property
    def stripe_customer_id(self):
        """Gets the stripe_customer_id of this OrmOrganization.  # noqa: E501


        :return: The stripe_customer_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._stripe_customer_id

    @stripe_customer_id.setter
    def stripe_customer_id(self, stripe_customer_id):
        """Sets the stripe_customer_id of this OrmOrganization.


        :param stripe_customer_id: The stripe_customer_id of this OrmOrganization.  # noqa: E501
        :type stripe_customer_id: str
        """

        self._stripe_customer_id = stripe_customer_id

    @property
    def stripe_subscription_id(self):
        """Gets the stripe_subscription_id of this OrmOrganization.  # noqa: E501


        :return: The stripe_subscription_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._stripe_subscription_id

    @stripe_subscription_id.setter
    def stripe_subscription_id(self, stripe_subscription_id):
        """Sets the stripe_subscription_id of this OrmOrganization.


        :param stripe_subscription_id: The stripe_subscription_id of this OrmOrganization.  # noqa: E501
        :type stripe_subscription_id: str
        """

        self._stripe_subscription_id = stripe_subscription_id

    @property
    def stripe_subscription_items(self):
        """Gets the stripe_subscription_items of this OrmOrganization.  # noqa: E501


        :return: The stripe_subscription_items of this OrmOrganization.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._stripe_subscription_items

    @stripe_subscription_items.setter
    def stripe_subscription_items(self, stripe_subscription_items):
        """Sets the stripe_subscription_items of this OrmOrganization.


        :param stripe_subscription_items: The stripe_subscription_items of this OrmOrganization.  # noqa: E501
        :type stripe_subscription_items: dict(str, object)
        """

        self._stripe_subscription_items = stripe_subscription_items

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmOrganization.  # noqa: E501


        :return: The updated_dt of this OrmOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmOrganization.


        :param updated_dt: The updated_dt of this OrmOrganization.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def user_discount_rate(self):
        """Gets the user_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The user_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._user_discount_rate

    @user_discount_rate.setter
    def user_discount_rate(self, user_discount_rate):
        """Sets the user_discount_rate of this OrmOrganization.


        :param user_discount_rate: The user_discount_rate of this OrmOrganization.  # noqa: E501
        :type user_discount_rate: float
        """

        self._user_discount_rate = user_discount_rate

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmOrganization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmOrganization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ProtoVolumeMountRequestSourceCode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'git_diff_file': 'str',
        'git_owner': 'str',
        'git_provider': 'str',
        'git_ref': 'str',
        'git_repo': 'str',
        'organization_credentials_id': 'int',
        'project_repository_id': 'int'
    }

    attribute_map = {
        'git_diff_file': 'git_diff_file',
        'git_owner': 'git_owner',
        'git_provider': 'git_provider',
        'git_ref': 'git_ref',
        'git_repo': 'git_repo',
        'organization_credentials_id': 'organization_credentials_id',
        'project_repository_id': 'project_repository_id'
    }

    def __init__(self, git_diff_file=None, git_owner=None, git_provider=None, git_ref=None, git_repo=None, organization_credentials_id=None, project_repository_id=None, local_vars_configuration=None):  # noqa: E501
        """ProtoVolumeMountRequestSourceCode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._git_diff_file = None
        self._git_owner = None
        self._git_provider = None
        self._git_ref = None
        self._git_repo = None
        self._organization_credentials_id = None
        self._project_repository_id = None
        self.discriminator = None

        if git_diff_file is not None:
            self.git_diff_file = git_diff_file
        if git_owner is not None:
            self.git_owner = git_owner
        if git_provider is not None:
            self.git_provider = git_provider
        if git_ref is not None:
            self.git_ref = git_ref
        if git_repo is not None:
            self.git_repo = git_repo
        self.organization_credentials_id = organization_credentials_id
        self.project_repository_id = project_repository_id

    @property
    def git_diff_file(self):
        """Gets the git_diff_file of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The git_diff_file of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: str
        """
        return self._git_diff_file

    @git_diff_file.setter
    def git_diff_file(self, git_diff_file):
        """Sets the git_diff_file of this ProtoVolumeMountRequestSourceCode.


        :param git_diff_file: The git_diff_file of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type git_diff_file: str
        """

        self._git_diff_file = git_diff_file

    @property
    def git_owner(self):
        """Gets the git_owner of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The git_owner of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: str
        """
        return self._git_owner

    @git_owner.setter
    def git_owner(self, git_owner):
        """Sets the git_owner of this ProtoVolumeMountRequestSourceCode.


        :param git_owner: The git_owner of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type git_owner: str
        """

        self._git_owner = git_owner

    @property
    def git_provider(self):
        """Gets the git_provider of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The git_provider of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: str
        """
        return self._git_provider

    @git_provider.setter
    def git_provider(self, git_provider):
        """Sets the git_provider of this ProtoVolumeMountRequestSourceCode.


        :param git_provider: The git_provider of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type git_provider: str
        """
        allowed_values = ["github"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and git_provider not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `git_provider` ({0}), must be one of {1}"  # noqa: E501
                .format(git_provider, allowed_values)
            )

        self._git_provider = git_provider

    @property
    def git_ref(self):
        """Gets the git_ref of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The git_ref of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: str
        """
        return self._git_ref

    @git_ref.setter
    def git_ref(self, git_ref):
        """Sets the git_ref of this ProtoVolumeMountRequestSourceCode.


        :param git_ref: The git_ref of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type git_ref: str
        """

        self._git_ref = git_ref

    @property
    def git_repo(self):
        """Gets the git_repo of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The git_repo of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: str
        """
        return self._git_repo

    @git_repo.setter
    def git_repo(self, git_repo):
        """Sets the git_repo of this ProtoVolumeMountRequestSourceCode.


        :param git_repo: The git_repo of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type git_repo: str
        """

        self._git_repo = git_repo

    @property
    def organization_credentials_id(self):
        """Gets the organization_credentials_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The organization_credentials_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: int
        """
        return self._organization_credentials_id

    @organization_credentials_id.setter
    def organization_credentials_id(self, organization_credentials_id):
        """Sets the organization_credentials_id of this ProtoVolumeMountRequestSourceCode.


        :param organization_credentials_id: The organization_credentials_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type organization_credentials_id: int
        """

        self._organization_credentials_id = organization_credentials_id

    @property
    def project_repository_id(self):
        """Gets the project_repository_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501


        :return: The project_repository_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :rtype: int
        """
        return self._project_repository_id

    @project_repository_id.setter
    def project_repository_id(self, project_repository_id):
        """Sets the project_repository_id of this ProtoVolumeMountRequestSourceCode.


        :param project_repository_id: The project_repository_id of this ProtoVolumeMountRequestSourceCode.  # noqa: E501
        :type project_repository_id: int
        """

        self._project_repository_id = project_repository_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtoVolumeMountRequestSourceCode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProtoVolumeMountRequestSourceCode):
            return True

        return self.to_dict() != other.to_dict()
